[Bf-blender-cvs] [87a3cb3bffd] master: Cleanup: `Neighbour` -> `Neighbor`. and other minor UI messages fixes.

Bastien Montagne noreply at git.blender.org
Mon Oct 4 11:15:21 CEST 2021


Commit: 87a3cb3bffd810f71c9af114a5b8fe8d4f029cf7
Author: Bastien Montagne
Date:   Mon Oct 4 11:08:33 2021 +0200
Branches: master
https://developer.blender.org/rB87a3cb3bffd810f71c9af114a5b8fe8d4f029cf7

Cleanup: `Neighbour` -> `Neighbor`. and other minor UI messages fixes.

Blender English should use 'American' variants, not 'British' variants.

===================================================================

M	release/scripts/modules/bl_i18n_utils/utils_spell_check.py
M	release/scripts/presets/keyconfig/keymap_data/blender_default.py
M	release/scripts/startup/bl_ui/space_view3d.py
M	source/blender/blenkernel/intern/gpencil_curve.c
M	source/blender/editors/animation/keyframes_keylist.cc
M	source/blender/editors/armature/armature_intern.h
M	source/blender/editors/armature/armature_ops.c
M	source/blender/editors/armature/pose_slide.c
M	source/blender/makesrna/intern/rna_gpencil_modifier.c

===================================================================

diff --git a/release/scripts/modules/bl_i18n_utils/utils_spell_check.py b/release/scripts/modules/bl_i18n_utils/utils_spell_check.py
index 0293d7143ec..c40b4593a19 100644
--- a/release/scripts/modules/bl_i18n_utils/utils_spell_check.py
+++ b/release/scripts/modules/bl_i18n_utils/utils_spell_check.py
@@ -176,6 +176,7 @@ class SpellChecker:
         "precalculate",
         "precomputing",
         "prefetch",
+        "prefilter", "prefiltering",
         "preload",
         "premultiply", "premultiplied",
         "prepass",
@@ -225,6 +226,7 @@ class SpellChecker:
         "subpath",
         "subsize",
         "substep", "substeps",
+        "substring",
         "targetless",
         "textbox", "textboxes",
         "tilemode",
@@ -731,6 +733,7 @@ class SpellChecker:
         "tma",
         "ui",
         "unix",
+        "uuid",
         "vbo", "vbos",
         "vr",
         "wxyz",
diff --git a/release/scripts/presets/keyconfig/keymap_data/blender_default.py b/release/scripts/presets/keyconfig/keymap_data/blender_default.py
index 8bf5ac500b0..14520c10a2b 100644
--- a/release/scripts/presets/keyconfig/keymap_data/blender_default.py
+++ b/release/scripts/presets/keyconfig/keymap_data/blender_default.py
@@ -4312,7 +4312,7 @@ def km_pose(params):
         ("pose.push", {"type": 'E', "value": 'PRESS', "ctrl": True}, None),
         ("pose.relax", {"type": 'E', "value": 'PRESS', "alt": True}, None),
         ("pose.breakdown", {"type": 'E', "value": 'PRESS', "shift": True}, None),
-        ("pose.blend_to_neighbour", {"type": 'E', "value": 'PRESS', "shift": True, "alt": True}, None),
+        ("pose.blend_to_neighbor", {"type": 'E', "value": 'PRESS', "shift": True, "alt": True}, None),
         op_menu("VIEW3D_MT_pose_propagate", {"type": 'P', "value": 'PRESS', "alt": True}),
         *(
             (("object.hide_collection",
diff --git a/release/scripts/startup/bl_ui/space_view3d.py b/release/scripts/startup/bl_ui/space_view3d.py
index 281c57b282f..59991eac92a 100644
--- a/release/scripts/startup/bl_ui/space_view3d.py
+++ b/release/scripts/startup/bl_ui/space_view3d.py
@@ -3443,7 +3443,7 @@ class VIEW3D_MT_pose_slide(Menu):
         layout.operator("pose.push")
         layout.operator("pose.relax")
         layout.operator("pose.breakdown")
-        layout.operator("pose.blend_to_neighbour")
+        layout.operator("pose.blend_to_neighbor")
 
 
 class VIEW3D_MT_pose_propagate(Menu):
@@ -3596,7 +3596,7 @@ class VIEW3D_MT_pose_context_menu(Menu):
         layout.operator("pose.push")
         layout.operator("pose.relax")
         layout.operator("pose.breakdown")
-        layout.operator("pose.blend_to_neighbour")
+        layout.operator("pose.blend_to_neighbor")
 
         layout.separator()
 
diff --git a/source/blender/blenkernel/intern/gpencil_curve.c b/source/blender/blenkernel/intern/gpencil_curve.c
index 3819c0699f4..98e481e6ea8 100644
--- a/source/blender/blenkernel/intern/gpencil_curve.c
+++ b/source/blender/blenkernel/intern/gpencil_curve.c
@@ -1167,7 +1167,7 @@ void BKE_gpencil_editcurve_recalculate_handles(bGPDstroke *gps)
     bGPDcurve_point *gpc_pt = &gpc->curve_points[i];
     bGPDcurve_point *gpc_pt_prev = &gpc->curve_points[i - 1];
     bGPDcurve_point *gpc_pt_next = &gpc->curve_points[i + 1];
-    /* update handle if point or neighbour is selected */
+    /* update handle if point or neighbor is selected */
     if (gpc_pt->flag & GP_CURVE_POINT_SELECT || gpc_pt_prev->flag & GP_CURVE_POINT_SELECT ||
         gpc_pt_next->flag & GP_CURVE_POINT_SELECT) {
       BezTriple *bezt = &gpc_pt->bezt;
diff --git a/source/blender/editors/armature/armature_intern.h b/source/blender/editors/armature/armature_intern.h
index 696355324e6..3a6761ba915 100644
--- a/source/blender/editors/armature/armature_intern.h
+++ b/source/blender/editors/armature/armature_intern.h
@@ -216,7 +216,7 @@ void POSE_OT_relax(struct wmOperatorType *ot);
 void POSE_OT_push_rest(struct wmOperatorType *ot);
 void POSE_OT_relax_rest(struct wmOperatorType *ot);
 void POSE_OT_breakdown(struct wmOperatorType *ot);
-void POSE_OT_blend_to_neighbours(struct wmOperatorType *ot);
+void POSE_OT_blend_to_neighbors(struct wmOperatorType *ot);
 
 void POSE_OT_propagate(struct wmOperatorType *ot);
 
diff --git a/source/blender/editors/armature/armature_ops.c b/source/blender/editors/armature/armature_ops.c
index a1070a8823a..75b0455d026 100644
--- a/source/blender/editors/armature/armature_ops.c
+++ b/source/blender/editors/armature/armature_ops.c
@@ -150,7 +150,7 @@ void ED_operatortypes_armature(void)
   WM_operatortype_append(POSE_OT_push_rest);
   WM_operatortype_append(POSE_OT_relax_rest);
   WM_operatortype_append(POSE_OT_breakdown);
-  WM_operatortype_append(POSE_OT_blend_to_neighbours);
+  WM_operatortype_append(POSE_OT_blend_to_neighbors);
 }
 
 void ED_operatormacros_armature(void)
diff --git a/source/blender/editors/armature/pose_slide.c b/source/blender/editors/armature/pose_slide.c
index b273d3aac76..ed8a35f779b 100644
--- a/source/blender/editors/armature/pose_slide.c
+++ b/source/blender/editors/armature/pose_slide.c
@@ -914,7 +914,7 @@ static void pose_slide_draw_status(bContext *C, tPoseSlideOp *pso)
       strcpy(mode_str, TIP_("Breakdown"));
       break;
     case POSESLIDE_BLEND:
-      strcpy(mode_str, TIP_("Blend To Neighbour"));
+      strcpy(mode_str, TIP_("Blend To Neighbor"));
       break;
 
     default:
@@ -1709,7 +1709,7 @@ void POSE_OT_breakdown(wmOperatorType *ot)
 }
 
 /* ........................ */
-static int pose_slide_blend_to_neighbours_invoke(bContext *C, wmOperator *op, const wmEvent *event)
+static int pose_slide_blend_to_neighbors_invoke(bContext *C, wmOperator *op, const wmEvent *event)
 {
   /* Initialize data. */
   if (pose_slide_init(C, op, POSESLIDE_BLEND) == 0) {
@@ -1721,7 +1721,7 @@ static int pose_slide_blend_to_neighbours_invoke(bContext *C, wmOperator *op, co
   return pose_slide_invoke_common(C, op, event);
 }
 
-static int pose_slide_blend_to_neighbours_exec(bContext *C, wmOperator *op)
+static int pose_slide_blend_to_neighbors_exec(bContext *C, wmOperator *op)
 {
   tPoseSlideOp *pso;
 
@@ -1737,16 +1737,16 @@ static int pose_slide_blend_to_neighbours_exec(bContext *C, wmOperator *op)
   return pose_slide_

@@ Diff output truncated at 10240 characters. @@



More information about the Bf-blender-cvs mailing list
diff --git a/source/blender/editors/animation/keyframes_keylist.cc b/source/blender/editors/animation/keyframes_keylist.cc
index c1a18196a3a..7d08e416d0d 100644
--- a/source/blender/editors/animation/keyframes_keylist.cc
+++ b/source/blender/editors/animation/keyframes_keylist.cc
@@ -564,9 +564,9 @@ static void nupdate_ak_masklayshape(ActKeyColumn *ak, void *data)
 using KeylistCreateColumnFunction = std::function<ActKeyColumn *(void *userdata)>;
 using KeylistUpdateColumnFunction = std::function<void(ActKeyColumn *, void *)>;
 
 /* `ED_keylist_find_neighbour_front_to_back` is called before the runtime can be initialized so we
  * cannot use bin searching. */
-static ActKeyColumn *ED_keylist_find_neighbour_front_to_back(ActKeyColumn *cursor, float cfra)
+static ActKeyColumn *ED_keylist_find_neighbor_front_to_back(ActKeyColumn *cursor, float cfra)
 {
   while (cursor->next && cursor->next->cfra <= cfra) {
     cursor = cursor->next;
@@ -574,9 +574,9 @@ static ActKeyColumn *ED_keylist_find_neighbour_front_to_back(ActKeyColumn *curso
   return cursor;
 }
 
 /* `ED_keylist_find_neighbour_back_to_front` is called before the runtime can be initialized so we
  * cannot use bin searching. */
-static ActKeyColumn *ED_keylist_find_neighbour_back_to_front(ActKeyColumn *cursor, float cfra)
+static ActKeyColumn *ED_keylist_find_neighbor_back_to_front(ActKeyColumn *cursor, float cfra)
 {
   while (cursor->prev && cursor->prev->cfra >= cfra) {
     cursor = cursor->prev;
@@ -585,14 +585,14 @@ static ActKeyColumn *ED_keylist_find_neighbour_back_to_front(ActKeyColumn *curso
 }
 
 /*
  * `ED_keylist_find_exact_or_neighbour_column` is called before the runtime can be initialized so
  * we cannot use bin searching.
  *
  * This function is called to add or update columns in the keylist.
  * Typically columns are sorted by frame number so keeping track of the last_accessed_column
  * reduces searching.
  */
-static ActKeyColumn *ED_keylist_find_exact_or_neighbour_column(AnimKeylist *keylist, float cfra)
+static ActKeyColumn *ED_keylist_find_exact_or_neighbor_column(AnimKeylist *keylist, float cfra)
 {
   BLI_assert(!keylist->is_runtime_initialized);
   if (ED_keylist_is_empty(keylist)) {
@@ -604,10 +604,10 @@ static ActKeyColumn *ED_keylist_find_exact_or_neighbour_column(AnimKeylist *keyl
   if (!is_cfra_eq(cursor->cfra, cfra)) {
     const bool walking_direction_front_to_back = cursor->cfra <= cfra;
     if (walking_direction_front_to_back) {
-      cursor = ED_keylist_find_neighbour_front_to_back(cursor, cfra);
+      cursor = ED_keylist_find_neighbor_front_to_back(cursor, cfra);
     }
     else {
-      cursor = ED_keylist_find_neighbour_back_to_front(cursor, cfra);
+      cursor = ED_keylist_find_neighbor_back_to_front(cursor, cfra);
     }
   }
 
@@ -633,7 +633,7 @@ static void ED_keylist_add_or_update_column(AnimKeylist *keylist,
     return;
   }
 
-  ActKeyColumn *nearest = ED_keylist_find_exact_or_neighbour_column(keylist, cfra);
+  ActKeyColumn *nearest = ED_keylist_find_exact_or_neighbor_column(keylist, cfra);
   if (is_cfra_eq(nearest->cfra, cfra)) {
     update_func(nearest, userdata);
   }
@@ -774,7 +774,7 @@ static void add_bezt_to_keyblocks_list(AnimKeylist *keylist, BezTriple *bezt, co
       if (is_cfra_lt(bezt[1].vec[1][0], bezt[0].vec[1][0])) {
         /* Backtrack to find the right location. */
         if (is_cfra_lt(bezt[1].vec[1][0], col->cfra)) {
-          ActKeyColumn *newcol = ED_keylist_find_exact_or_neighbour_column(keylist, col->cfra);
+          ActKeyColumn *newcol = ED_keylist_find_exact_or_neighbor_column(keylist, col->cfra);
 
           BLI_assert(newcol);
           BLI_assert(newcol->cfra == col->cfra);
@@ -564,9 +564,9 @@ static void nupdate_ak_masklayshape(ActKeyColumn *ak, void *data)
 using KeylistUpdateColumnFunction = std::function<void(ActKeyColumn *, void *)>;
 
-/* `ED_keylist_find_neighbour_front_to_back` is called before the runtime can be initialized so we
+/* `ED_keylist_find_neighbor_front_to_back` is called before the runtime can be initialized so we
  * cannot use bin searching. */
@@ -574,9 +574,9 @@ static ActKeyColumn *ED_keylist_find_neighbour_front_to_back(ActKeyColumn *curso
 }
 
-/* `ED_keylist_find_neighbour_back_to_front` is called before the runtime can be initialized so we
+/* `ED_keylist_find_neighbor_back_to_front` is called before the runtime can be initialized so we
  * cannot use bin searching. */
@@ -585,14 +585,14 @@ static ActKeyColumn *ED_keylist_find_neighbour_back_to_front(ActKeyColumn *curso
 
 /*
- * `ED_keylist_find_exact_or_neighbour_column` is called before the runtime can be initialized so
+ * `ED_keylist_find_exact_or_neighbor_column` is called before the runtime can be initialized so
  * we cannot use bin searching.
  *